# Django SNS Mobile Push Notifications


Send mobile push notification to IOS and android devices using Amazon SNS.

[![Documentation Status](https://readthedocs.org/projects/django-sns-mobile-push-notification/badge/?version=latest)](http://django-sns-mobile-push-notification.readthedocs.io/en/latest/?badge=latest)

Documentation
-----------
https://django-sns-mobile-push-notification.readthedocs.io/

Project Home
------------
https://github.com/fuzz-productions/django-sns-mobile-push-notification

PyPi
------------
https://pypi.python.org/pypi/django-sns-mobile-push-notification
